@@ -57,6 +57,10 @@
 #include <QtCore/private/qandroidextras_p.h>
 #endif
 
+#ifdef Q_OS_WIN
+#include <Windows.h>
+#endif
+
 #ifdef Q_OS_ANDROID
 int __attribute__((visibility("default"))) main(int argc, char *argv[])
 #else
@@ -82,9 +86,14 @@ int main(int argc, char *argv[])
 
     qputenv("QT_LOGGING_RULES", "org.kde.elisa*=true");
 #endif
+
 #ifdef Q_OS_WIN
-    qputenv("QT_LOGGING_RULES", "org.kde.elisa*=true");
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        freopen("CONOUT$", "w", stdout);
+        freopen("CONOUT$", "w", stderr);
+    }
 #endif
+
     qputenv("QT_GSTREAMER_USE_PLAYBIN_VOLUME", "true");
 
     QApplication app(argc, argv);
@@ -105,10 +114,6 @@ int main(int argc, char *argv[])
 #endif
 #endif
 
-#if KFCrash_FOUND
-    KCrash::initialize();
-#endif
-
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("elisa")));
 
     KAboutData aboutData( QStringLiteral("elisa"),
@@ -128,10 +133,9 @@ int main(int argc, char *argv[])
     aboutData.addCredit(QStringLiteral("Jérôme Guidon"), i18nc("@label", "Support for online radios"), QStringLiteral("guidon@live.fr"));
 
     KAboutData::setApplicationData(aboutData);
-
-    qmlRegisterSingletonType("org.kde.elisa.about", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
-        return engine->toScriptValue(KAboutData::applicationData());
-    });
+#if KFCrash_FOUND
+    KCrash::initialize();
+#endif
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
